#
# Copyright (C) 2014 The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

LOCAL_PATH := $(call my-dir)

include $(CLEAR_VARS)

ifeq (linux,$(findstring linux,$(TARGET_PRODUCT)))
# Build tools on linux target.

Common_libmtd_LOCAL_SRC_FILES:= \
	lib/libcrc32.c \
	lib/libfec.c \
	lib/libmtd.c \
	lib/libmtd_legacy.c \


Common_libubi_LOCAL_SRC_FILES:= \
	ubi-utils/dictionary.c \
	ubi-utils/ubiutils-common.c \
	ubi-utils/libiniparser.c \
	ubi-utils/libscan.c \
	ubi-utils/libubi.c  \
	ubi-utils/libubigen.c \


Common_LOCAL_CFLAGS += \
    -Os \
    -Wno-char-subscripts \
    -Wno-sign-compare \
    -Wno-uninitialized \
    -Wno-unused-parameter \
    -funsigned-char \
    -ffunction-sections -fdata-sections \
    -fno-asynchronous-unwind-tables \
    -DANDROID

Common_LOCAL_C_INCLUDES := \
	$(LOCAL_PATH)/include

Common_ubi_LOCAL_C_INCLUDES := \
	$(LOCAL_PATH)/include \
	$(LOCAL_PATH)/ubi-utils/include


Common_LOCAL_MODULE_TAGS := eng userdebug

Common_bin_LOCAL_MODULE_PATH :=  $(TARGET_OUT_OPTIONAL_EXECUTABLES)
Common_lib_LOCAL_MODULE_PATH := $(TARGET_OUT)/lib

ifeq (,$(findstring linux,$(TARGET_PRODUCT)))
# make on android.
Common_LOCAL_SHARED_LIBRARIES := libc
else
# make on simple linux.
Common_LOCAL_SHARED_LIBRARIES :=
endif

Common_mtd_LOCAL_SHARED_LIBRARIES := $(Common_LOCAL_SHARED_LIBRARIES)     libmtd
Common_ubi_LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES) libubi

#
# Build Shared library libmtd
#

LOCAL_MODULE:= libmtd
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := $(Common_libmtd_LOCAL_SRC_FILES)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_MODULE_PATH := $(Common_lib_LOCAL_MODULE_PATH)

include $(BUILD_SHARED_LIBRARY)

#
# Build flash_erase
#
include $(CLEAR_VARS)

LOCAL_MODULE := flash_erase
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := \
	flash_erase.c

LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build flash_lock
#
include $(CLEAR_VARS)

LOCAL_MODULE := flash_lock
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := \
	flash_lock.c

LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build flash_unlock
#
include $(CLEAR_VARS)

LOCAL_MODULE := flash_unlock
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := \
	flash_unlock.c

LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build flashcp
#
include $(CLEAR_VARS)

LOCAL_MODULE := flashcp
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := \
	flashcp.c

LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build mtd_debug
#
include $(CLEAR_VARS)

LOCAL_MODULE := mtd_debug
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := \
	mtd_debug.c

LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build nanddump
#
include $(CLEAR_VARS)

LOCAL_MODULE := nanddump
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := \
	nanddump.c

LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build nandtest
#
include $(CLEAR_VARS)

LOCAL_MODULE := nandtest
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := \
	nandtest.c

LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build nandwrite
#
include $(CLEAR_VARS)

LOCAL_MODULE := nandwrite
LOCAL_SRC_FILES := \
	nandwrite.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build Shared library libubi
#
include $(CLEAR_VARS)

LOCAL_MODULE:= libubi
LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_SRC_FILES := $(Common_libubi_LOCAL_SRC_FILES)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_mtd_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_lib_LOCAL_MODULE_PATH)

include $(BUILD_SHARED_LIBRARY)

#
# Build mtdinfo
#
include $(CLEAR_VARS)

LOCAL_MODULE := mtdinfo
LOCAL_SRC_FILES := \
	ubi-utils/mtdinfo.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubiattach
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubiattach
LOCAL_SRC_FILES := \
	ubi-utils/ubiattach.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubiblock
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubiblock
LOCAL_SRC_FILES := \
	ubi-utils/ubiblock.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubicrc32
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubicrc32
LOCAL_SRC_FILES := \
	ubi-utils/ubicrc32.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubidetach
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubidetach
LOCAL_SRC_FILES := \
	ubi-utils/ubidetach.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)


#
# Build ubiformat
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubiformat
LOCAL_SRC_FILES := \
	ubi-utils/ubiformat.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubimkvol
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubimkvol
LOCAL_SRC_FILES := \
	ubi-utils/ubimkvol.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubinfo
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubinfo
LOCAL_SRC_FILES := \
	ubi-utils/ubinfo.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubinize
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubinize
LOCAL_SRC_FILES := \
	ubi-utils/ubinize.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubirename
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubirename
LOCAL_SRC_FILES := \
	ubi-utils/ubirename.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubirmvol
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubirmvol
LOCAL_SRC_FILES := \
	ubi-utils/ubirmvol.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubirsvol
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubirsvol
LOCAL_SRC_FILES := \
	ubi-utils/ubirsvol.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build ubiupdatevol
#
include $(CLEAR_VARS)

LOCAL_MODULE := ubiupdatevol
LOCAL_SRC_FILES := \
	ubi-utils/ubiupdatevol.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)

#
# Build mkfs.ubifs
# @todo prepare lzo library, and compile mkfs.ubifs.
#
ifeq (build_mkfs.ubifs,)
include $(CLEAR_VARS)

LOCAL_MODULE := mkfs.ubifs
LOCAL_SRC_FILES := \
	mkfs.ubifs/compr.c \
	mkfs.ubifs/crc16.c  \
	mkfs.ubifs/devtable.c \
	mkfs.ubifs/lpt.c  \
	mkfs.ubifs/mkfs.ubifs.c

LOCAL_MODULE_TAGS := $(Common_LOCAL_MODULE_TAGS)
LOCAL_CFLAGS += $(Common_LOCAL_CFLAGS)
LOCAL_C_INCLUDES := $(Common_ubi_LOCAL_C_INCLUDES)
LOCAL_SHARED_LIBRARIES := $(Common_ubi_LOCAL_SHARED_LIBRARIES)
LOCAL_MODULE_PATH := $(Common_bin_LOCAL_MODULE_PATH)

include $(BUILD_EXECUTABLE)
endif

# (linux,$(findstring linux,$(TARGET_PRODUCT)))
endif
